summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolder.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolder.h')
-rw-r--r--kmail/kmfolder.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/kmfolder.h b/kmail/kmfolder.h
index 351e55b45..60db26661 100644
--- a/kmail/kmfolder.h
+++ b/kmail/kmfolder.h
@@ -60,7 +60,7 @@ typedef TQValueList<TQ_UINT32> SerNumList;
*
* @section Accounts
* The accounts (of KMail) that are fed into the folder are
- * represented as the children of the folder. They are only stored here
+ * represented as the tqchildren of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
@@ -169,10 +169,10 @@ public:
/** Specify, that the folder can't contain mails. */
void setNoContent(bool aNoContent);
- /** Returns, if the folder can't have children */
+ /** Returns, if the folder can't have tqchildren */
bool noChildren() const;
- /** Specify, that the folder can't have children */
+ /** Specify, that the folder can't have tqchildren */
void setNoChildren(bool aNoChildren);
/** Read message at given index. Indexing starts at zero */
@@ -273,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
/** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
- void msgStatusChanged( const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus,
+ void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus,
int idx);
/** Open folder for access.
@@ -490,10 +490,10 @@ public:
int writeIndex( bool createEmptyIndex = false );
/** Set the status of the message at index @p idx to @p status. */
- void seStatus(int idx, KMMsgStatus status, bool toggle=false);
+ void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
/** Icon related methods */
bool useCustomIcons() const { return mUseCustomIcons; }
@@ -273,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
- /** Called by KMMsgBase::seStatus when status of a message has changed
+ /** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */